@@ -1,6 +1,6 @@
 import plib
 
-root = plib.Path(__file__).parent.parent
+root = plib.Path(__file__).parent
 
 
 class Path(plib.Path):
